@@ -1,13 +1,9 @@
 --local configs = require("lspconfig.configs")
-local nvim_lsp = require("lspconfig")
-
 return {
     lsp = {
         neocmake = {
             cmd = vim.lsp.rpc.connect('127.0.0.1', 9257),
-            root_dir = function(fname)
-                return nvim_lsp.util.find_git_ancestor(fname)
-            end,
+            root_markers = { ".git" },
             on_attach = function(client, bufnr)
                 vim.notify("Lsp Start")
                 require("cmps.cmp_onattach")(client, bufnr)
@@ -33,6 +29,7 @@ return {
                 },
                 scan_cmake_in_package = false,
                 semantic_token = false,
+                use_snippets = false
             }
         }
     }
