@@ -131,7 +131,10 @@ pub async fn getcomplete<P: AsRef<Path>>(
     let current_point = location.to_point();
     let postype = get_pos_type(current_point, tree.root_node(), source);
     match postype {
-        PositionType::VarOrFun | PositionType::TargetLink | PositionType::TargetInclude => {
+        PositionType::VarOrFun
+        | PositionType::TargetLink
+        | PositionType::TargetInclude
+        | PositionType::ArgumentOrList => {
             let mut cached_completion = get_cached_completion(local_path).await;
             if !cached_completion.is_empty() {
                 complete.append(&mut cached_completion);
@@ -153,7 +156,9 @@ pub async fn getcomplete<P: AsRef<Path>>(
                 complete.append(&mut message);
             }
 
-            if let Ok(messages) = &*BUILTIN_COMMAND {
+            if let Ok(messages) = &*BUILTIN_COMMAND
+                && !matches!(postype, PositionType::ArgumentOrList)
+            {
                 complete.append(&mut messages.clone());
             }
             if let Ok(messages) = &*BUILTIN_VARIABLE {
@@ -197,7 +202,7 @@ pub async fn getcomplete<P: AsRef<Path>>(
     }
 }
 
-/// NOTE: postype can only be VarOrFun | TargetLink | TargetInclude
+/// NOTE: postype can only be VarOrFun | TargetLink | TargetInclude | ArgumentOrList
 /// get the variable from the loop
 /// use position to make only can complete which has show before
 #[allow(clippy::too_many_arguments)]
@@ -214,13 +219,16 @@ fn getsubcomplete<P: AsRef<Path>>(
 ) -> Option<Vec<CompletionItem>> {
     assert!(matches!(
         postype,
-        PositionType::VarOrFun | PositionType::TargetLink | PositionType::TargetInclude
+        PositionType::VarOrFun
+            | PositionType::TargetLink
+            | PositionType::TargetInclude
+            | PositionType::ArgumentOrList
     ));
     let local_path = local_path.as_ref();
-    if let Some(location) = location {
-        if input.start_position().row as u32 > location.line {
-            return None;
-        }
+    if let Some(location) = location
+        && input.start_position().row as u32 > location.line
+    {
+        return None;
     }
 
     let mut course = input.walk();
@@ -230,11 +238,11 @@ fn getsubcomplete<P: AsRef<Path>>(
         comments: vec![],
     };
     for child in input.children(&mut course) {
-        if let Some(location) = location {
-            if child.start_position().row as u32 > location.line {
-                // if this child is below row, then break all loop
-                break;
-            }
+        if let Some(location) = location
+            && child.start_position().row as u32 > location.line
+        {
+            // if this child is below row, then break all loop
+            break;
         }
         match child.kind() {
             CMakeNodeKinds::LINE_COMMENT => {
@@ -875,7 +883,7 @@ Example using both :command:`configure_package_config_file` and
    check_required_components(Foo)
 #]=======================================================================]
         "#;
-    assert_eq!(rst_doc_read(doc, "FileExample.cmake").len(), 2)
+    assert_eq!(rst_doc_read(doc, "FileExample.cmake").len(), 2);
 }
 
 #[test]
