@@ -100,7 +100,7 @@ pub fn get_point_string<'a>(location: Point, root: Node, source: &Vec<&'a str>)
                 .is_some_and(|message| !BLACK_POS_STRING.contains(message))
             {
                 return mabepos;
-            };
+            }
         }
         // if is the same line
         if child.start_position().row == child.end_position().row
@@ -232,7 +232,7 @@ fn location_range_contain(location: Point, range_node: Node) -> bool {
     let range_end_position = range_node.end_position();
     if range_end_position.row < location.row || range_start_position.row > location.row {
         return false;
-    };
+    }
 
     if range_start_position.row == location.row && range_start_position.column > location.column {
         return false;
@@ -243,7 +243,7 @@ fn location_range_contain(location: Point, range_node: Node) -> bool {
     true
 }
 
-pub fn is_comment(location: Point, root: Node) -> bool {
+pub fn contain_comment(location: Point, root: Node) -> bool {
     if !location_range_contain(location, root) {
         return false;
     }
@@ -261,7 +261,7 @@ pub fn is_comment(location: Point, root: Node) -> bool {
         {
             return true;
         }
-        if child.child_count() != 0 && is_comment(location, child) {
+        if child.child_count() != 0 && contain_comment(location, child) {
             return true;
         }
     }
@@ -320,7 +320,7 @@ fn get_pos_type_inner<'a>(
                     if child_count >= 2
                         && !location_range_contain(location, first_argument)
                         && input_type == PositionType::FindPackage
-                        && node_source.iter().any(|context| *context == "COMPONENTS")
+                        && node_source.contains(&"COMPONENTS")
                     {
                         return PositionType::FindPackageSpace(val);
                     }
@@ -349,7 +349,12 @@ fn get_pos_type_inner<'a>(
                 PositionType::FindPkgConfig => input_type,
                 _ => PositionType::VarOrFun,
             },
-            CMakeNodeKinds::LINE_COMMENT | CMakeNodeKinds::BRACKET_COMMENT => PositionType::Comment,
+            CMakeNodeKinds::LINE_COMMENT
+            | CMakeNodeKinds::BRACKET_COMMENT
+            | CMakeNodeKinds::BRACKET_COMMENT_CONTENT
+            | CMakeNodeKinds::BRACKET_COMMENT_CLOSE
+            | CMakeNodeKinds::BRACKET_COMMENT_OPEN
+            | CMakeNodeKinds::BRACKET_ARGUMENT_OPEN => PositionType::Comment,
             _ => PositionType::VarOrFun,
         };
 
@@ -379,10 +384,10 @@ fn get_pos_type_inner<'a>(
                 #[cfg(unix)]
                 PositionType::FindPkgConfig => {
                     let name = get_point_string(location, root, source);
-                    if let Some(name) = name {
-                        if name.to_lowercase() == "pkg_check_modules" {
-                            return PositionType::Unknown;
-                        }
+                    if let Some(name) = name
+                        && name.to_lowercase() == "pkg_check_modules"
+                    {
+                        return PositionType::Unknown;
                     }
                     return jumptype;
                 }
@@ -392,13 +397,13 @@ fn get_pos_type_inner<'a>(
                     match currenttype {
                         PositionType::Unknown => {}
                         _ => return currenttype,
-                    };
+                    }
                 }
                 PositionType::Unknown
                 | PositionType::Comment
                 | PositionType::ArgumentOrList
                 | PositionType::FunOrMacroArgs => {
-                    return get_pos_type_inner(location, child, source, jumptype)
+                    return get_pos_type_inner(location, child, source, jumptype);
                 }
                 // NOTE: it should be designed to cannot be reach
                 PositionType::FindPackageSpace(_) | PositionType::FunOrMacroIdentifier => {
@@ -420,10 +425,10 @@ fn tst_line_comment() {
 A#ss\" #sss)";
     let mut parse = tree_sitter::Parser::new();
     parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
-    let tree = parse.parse(&source, None).unwrap();
+    let tree = parse.parse(source, None).unwrap();
     let input = tree.root_node();
-    assert!(!is_comment(Point { row: 1, column: 1 }, input));
-    assert!(is_comment(Point { row: 1, column: 8 }, input));
+    assert!(!contain_comment(Point { row: 1, column: 1 }, input));
+    assert!(contain_comment(Point { row: 1, column: 8 }, input));
 }
 
 #[test]
@@ -445,7 +450,7 @@ include("abcd/efg.cmake")
     use crate::consts::TREESITTER_CMAKE_LANGUAGE;
     let mut parse = tree_sitter::Parser::new();
     parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
-    let tree = parse.parse(&source, None).unwrap();
+    let tree = parse.parse(source, None).unwrap();
     let input = tree.root_node();
     let source_lines = source.lines().collect();
     let pos_str_1 = get_point_string(Point { row: 2, column: 4 }, input, &source_lines).unwrap();
@@ -481,7 +486,7 @@ endmacro()
     use crate::consts::TREESITTER_CMAKE_LANGUAGE;
     let mut parse = tree_sitter::Parser::new();
     parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
-    let tree = parse.parse(&source, None).unwrap();
+    let tree = parse.parse(source, None).unwrap();
     let input = tree.root_node();
 
     assert_eq!(
@@ -572,5 +577,5 @@ endmacro()
     assert_eq!(
         get_pos_type(Point { row: 17, column: 8 }, input, source,),
         PositionType::FunOrMacroIdentifier
-    )
+    );
 }
